@@ -1,16 +1,15 @@
 import sys
+from argparse import Namespace
 
 import tomli
-from pdm.project.core import Project
 from pdm.cli.commands.base import BaseCommand
-from argparse import Namespace
+from pdm.project.core import Project
+
 
 class MinaPackagesListCommand(BaseCommand):
     def handle(self, project: Project, options: Namespace):
         if not (project.root / "pyproject.toml").exists():
-            project.core.ui.echo(
-                "No pyproject.toml found.", err=True
-            )
+            project.core.ui.echo("No pyproject.toml found.", err=True)
             sys.exit(1)
         pyproj = tomli.loads((project.root / "pyproject.toml").read_text())
         mina_packages = pyproj.get("tool", {}).get("mina", {}).get("packages", [])
@@ -20,8 +19,10 @@ class MinaPackagesListCommand(BaseCommand):
             )
             sys.exit(0)
         project.core.ui.echo(
-            "\n".join([
-                "Found mina packages:",
-                *[f" - {package}" for package in mina_packages],
-            ])
+            "\n".join(
+                [
+                    "Found mina packages:",
+                    *[f" - {package}" for package in mina_packages],
+                ]
+            )
         )
